#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Network Station |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: wiz_archive.tcl                                  |
#| Last Modified: April 12, 2000 by Chris Glendenning         |
#| Changes: added logging function 04.12.00 RAH               |
#| Description: allows the user to backup and restore the     |
#|     compact flash image they have created                  |
#|     also contains image_back{} and image_restore{}         |
#`------------------------------------------------------------'

proc backup_restore {show_next_back} {
    check_for_win {.win}
    global lh
    puts $lh [format "%s" "Starting backup_restore"]
    puts $lh [format "%s=%s" "Running_in_Wizmode" "$show_next_back"]
    flush $lh

    global BOOTDIR
    global NETSCAPE_ROOT
    global IBM_JVM_ROOT
    global REAL7_ROOT
    global INSTALL_DEST
    global INSTALL_SOURCE
    global FVWM2_SOURCE
    global FVWM2_ICON_SOURCE
    global GIMP_SOURCE
    global GTK_SOURCE
    global GIMP_LIB_SOURCE


    if {[winfo exists .win]} {
	wm deiconify .win
	return
    }

    set win [toplevel .win -width 500 -height 300]
    wm title .win {IBM Linux Setup - Compact Flash Image Backup}
    wm geometry .win 500x300+312+134
    wm resizable .win 0 0
    centerwin {.win}

    frame .win.main -width 500 -height 300
    frame .win.sep -width 500 -height 2 -borderwidth 2 -relief sunken

    if {$show_next_back} {
	button .win.finish -text {Finish} -command {destroy .win}
	button .win.back -text {< Back} -command {ChangePage "choose_settings"\
	  "1"}
	place .win.back -x 8 -y 260
	place .win.finish -x 85 -y 260
    }

    place .win.main -x 0 -y 0
    place .win.sep -x 0 -y 245

    label .win.message -justify "left" -text " Now that your Compact Flash\
      Image is built, you can\n choose to backup your image for easy Compact\
      Flash\n replication and restoration.  If you would like to\n backup your\
      current image please click Backup now,\n otherwise Click Finish to close\
      the Setup Program.\n"

    place .win.message -x 85 -y 20

    button .win.backup -text {Backup} -command image_backup
    button .win.restore -text {Restore} -command image_restore

    place .win.backup -x 160 -y 180
    place .win.restore -x 245 -y 180

}

########################################################################
#========================= Package Building ===========================#
########################################################################

proc image_backup {} {
    global BACKUP_SOURCE
    global lh
    puts $lh [format "%s" "Starting image_backup"]
    flush $lh

    toplevel .win.top -width 250 -height 150
    wm title .win.top "Backup Image Location"
    label .win.top.message -text "Backup Image to where?"
    entry .win.top.entry_backup_root
    button .win.top.button_browse -text "Browse" -command browse
    button .win.top.button_ok -text "Backup" -command finish

    wm geometry .win.top +400+400
    place .win.top.message -x 10 -y 20
    place .win.top.entry_backup_root -x 55 -y 50
    place .win.top.button_browse -x 170 -y 100
    place .win.top.button_ok -x 80 -y 100

    .win.top.entry_backup_root insert 0 $BACKUP_SOURCE
    .win.top.entry_backup_root select range 0 [string length $BACKUP_SOURCE]
    focus .win.top.entry_backup_root

    proc finish {} {
	global BACKUP_SOURCE
	global lh

	set BACKUP_SOURCE [.win.top.entry_backup_root get]
	puts $lh [format "%s->%s" "Archiving" "$BACKUP_SOURCE"]
	flush $lh
	destroy .win.top
	SaveDirInfo
	action_window "Saving Current Image....\nPlease Wait."\
	  "./image_backup.sh" "image_backup.log" "Backup Complete"
	return
    }

    proc browse {} {
	global BACKUP_SOURCE
	set types {
			{{Image Files} {.img}}
			
		}
	.win.top.entry_backup_root delete 0 [string length $BACKUP_SOURCE]
	set BACKUP_SOURCE [tk_getSaveFile -title "Backup Location"\
	  -filetypes $types -parent .win.top]
	.win.top.entry_backup_root insert 0 $BACKUP_SOURCE
	.win.top.entry_backup_root select range 0 [string length $BACKUP_SOURCE]
	focus .win.top.entry_backup_root
	return
    }

}

proc image_restore {} {
    global RESTORE_SOURCE
    global lh
    puts $lh [format "%s" "Starting image_restore"]
    flush $lh


    toplevel .win.top -width 250 -height 150
    wm title .win.top "Restore Image Location"
    label .win.top.message -text "Where is the Image you want to restore?"
    entry .win.top.entry_restore_root
    button .win.top.button_browse -text "Browse" -command browse
    button .win.top.button_ok -text "Restore" -command finish

    wm geometry .win.top +400+400
    place .win.top.message -x 10 -y 20
    place .win.top.entry_restore_root -x 55 -y 50
    place .win.top.button_browse -x 170 -y 100
    place .win.top.button_ok -x 80 -y 100

    .win.top.entry_restore_root insert 0 $RESTORE_SOURCE
    .win.top.entry_restore_root select range 0 [string length $RESTORE_SOURCE]
    focus .win.top.entry_restore_root

    proc finish {} {
	global RESTORE_SOURCE
	global lh
	set RESTORE_SOURCE [.win.top.entry_restore_root get]
	puts $lh [format "%s->%s" "Archiving" "$RESTORE_SOURCE"]
	flush $lh
	destroy .win.top
	SaveDirInfo
	action_window "Restoring Image from file....\nPlease Wait."\
	  "./image_restore.sh" "image_restore.log" "Restoration Complete"
	return
    }

    proc browse {} {
	global RESTORE_SOURCE
	set types {
			{{Image Files} {.img}}
			
		}
	.win.top.entry_restore_root delete 0 [string length $RESTORE_SOURCE]
	set RESTORE_SOURCE [tk_getOpenFile -title "Image Location"\
	  -filetypes $types -parent .win.top]
	.win.top.entry_restore_root insert 0 $RESTORE_SOURCE
	.win.top.entry_restore_root select range 0 [string length\
	  $RESTORE_SOURCE]
	focus .win.top.entry_restore_root
	return
    }

}
